MonetColor class

Inheritance

Properties

a → double
The alpha channel of this color.
finalinherited
alpha → int
The alpha channel of this color in an 8 bit value.
no setterinherited
b → double
The blue channel of this color.
finalinherited
blue → int
The blue channel of this color in an 8 bit value.
no setterinherited
colors → Map<int, Color>
final
colorSpace → ColorSpace
The color space of this color.
finalinherited
g → double
The green channel of this color.
finalinherited
green → int
The green channel of this color in an 8 bit value.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
keys → Iterable<int>
Returns the valid keys for accessing operator[].
no setterinherited
opacity → double
The alpha channel of this color as a double.
no setterinherited
r → double
The red channel of this color.
finalinherited
red → int
The red channel of this color in an 8 bit value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shade0 → Color
White.
no setter
shade10 → Color
The lightest shade.
no setter
shade100 → Color
The third lightest shade.
no setter
shade1000 → Color
Black.
no setter
shade200 → Color
The fouth lightest shade.
no setter
shade300 → Color
The fifth lightest shade.
no setter
shade400 → Color
The sixth lightest shade.
no setter
shade50 → Color
The second lightest shade.
no setter
shade500 → Color
The default shade.
no setter
shade600 → Color
The fourth darkest shade.
no setter
shade700 → Color
The third darkest shade.
no setter
shade800 → Color
The second darkest shade.
no setter
shade900 → Color
The darkest shade.
no setter
value → int
A 32 bit value representing this color.
no setterinherited

Methods

computeLuminance() → double
Returns a brightness value between 0 for darkest and 1 for lightest.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toARGB32() → int
Returns a 32-bit value representing this color.
inherited
toString() → String
A string representation of this object.
inherited
withAlpha(int a) → Color
Returns a new color that matches this color with the alpha channel replaced with a (which ranges from 0 to 255).
inherited
withBlue(int b) → Color
Returns a new color that matches this color with the blue channel replaced with b (which ranges from 0 to 255).
inherited
withGreen(int g) → Color
Returns a new color that matches this color with the green channel replaced with g (which ranges from 0 to 255).
inherited
withOpacity(double opacity) → Color
Returns a new color that matches this color with the alpha channel replaced with the given opacity (which ranges from 0.0 to 1.0).
inherited
withRed(int r) → Color
Returns a new color that matches this color with the red channel replaced with r (which ranges from 0 to 255).
inherited
withValues({double? alpha, double? red, double? green, double? blue, ColorSpace? colorSpace}) → Color
Returns a new color with the provided components updated.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int key) → Color?
Returns an element of the swatch table.
inherited