MonetColors class

Constructors

MonetColors({required MonetColor primary, required MonetColor secondary, required MonetColor tertiary, required MonetColor neutral, required MonetColor neutralVariant})
MonetColors.fromMap(Map<String, int> colors)
Creates an instance from a map of raw color names and int colors taken from the system.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
neutral → MonetColor
The neutral color.
final
neutralVariant → MonetColor
The neutral variant color.
final
primary → MonetColor
The primary accent color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → MonetColor
The secondary accent color.
final
tertiary → MonetColor
The tertiary accent color.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited